# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.period import Period
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.dash.periods.custom_xml_elements.custom_xml_elements_api import CustomXmlElementsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.adaptationsets_api import AdaptationsetsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.period_list_query_params import PeriodListQueryParams


class PeriodsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(PeriodsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.custom_xml_elements = CustomXmlElementsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.adaptationsets = AdaptationsetsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, period, **kwargs):
        # type: (string_types, Period, dict) -> Period
        """Add Period

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period: The Period to be added to the manifest
        :type period: Period, required
        :return: Period
        :rtype: Period
        """

        return self.api_client.post(
            '/encoding/manifests/dash/{manifest_id}/periods',
            period,
            path_params={'manifest_id': manifest_id},
            type=Period,
            **kwargs
        )

    def delete(self, manifest_id, period_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Period

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period to be deleted
        :type period_id: string_types, required
        :return: Id of the Period
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, period_id, **kwargs):
        # type: (string_types, string_types, dict) -> Period
        """Period Details

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :return: Period details
        :rtype: Period
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id},
            type=Period,
            **kwargs
        )

    def list(self, manifest_id, query_params=None, **kwargs):
        # type: (string_types, PeriodListQueryParams, dict) -> Period
        """List all Periods

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param query_params: Query parameters
        :type query_params: PeriodListQueryParams
        :return: List of Periods
        :rtype: Period
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods',
            path_params={'manifest_id': manifest_id},
            query_params=query_params,
            pagination_response=True,
            type=Period,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint
import six


class AzureAccount(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 subscription_id=None,
                 resource_group_id=None,
                 tenant_id=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, string_types) -> None
        super(AzureAccount, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._subscription_id = None
        self._resource_group_id = None
        self._tenant_id = None
        self.discriminator = None

        if subscription_id is not None:
            self.subscription_id = subscription_id
        if resource_group_id is not None:
            self.resource_group_id = resource_group_id
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AzureAccount, self), 'openapi_types'):
            types = getattr(super(AzureAccount, self), 'openapi_types')

        types.update({
            'subscription_id': 'string_types',
            'resource_group_id': 'string_types',
            'tenant_id': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AzureAccount, self), 'attribute_map'):
            attributes = getattr(super(AzureAccount, self), 'attribute_map')

        attributes.update({
            'subscription_id': 'subscriptionId',
            'resource_group_id': 'resourceGroupId',
            'tenant_id': 'tenantId'
        })
        return attributes

    @property
    def subscription_id(self):
        # type: () -> string_types
        """Gets the subscription_id of this AzureAccount.

        Your Azure Subscription ID (The ID of your subscription where you intend to run the Encoding VMs) (required)

        :return: The subscription_id of this AzureAccount.
        :rtype: string_types
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        # type: (string_types) -> None
        """Sets the subscription_id of this AzureAccount.

        Your Azure Subscription ID (The ID of your subscription where you intend to run the Encoding VMs) (required)

        :param subscription_id: The subscription_id of this AzureAccount.
        :type: string_types
        """

        if subscription_id is not None:
            if not isinstance(subscription_id, string_types):
                raise TypeError("Invalid type for `subscription_id`, type has to be `string_types`")

        self._subscription_id = subscription_id

    @property
    def resource_group_id(self):
        # type: () -> string_types
        """Gets the resource_group_id of this AzureAccount.

        The name of the resource group where you intend to run the Encoding VMs (required)

        :return: The resource_group_id of this AzureAccount.
        :rtype: string_types
        """
        return self._resource_group_id

    @resource_group_id.setter
    def resource_group_id(self, resource_group_id):
        # type: (string_types) -> None
        """Sets the resource_group_id of this AzureAccount.

        The name of the resource group where you intend to run the Encoding VMs (required)

        :param resource_group_id: The resource_group_id of this AzureAccount.
        :type: string_types
        """

        if resource_group_id is not None:
            if not isinstance(resource_group_id, string_types):
                raise TypeError("Invalid type for `resource_group_id`, type has to be `string_types`")

        self._resource_group_id = resource_group_id

    @property
    def tenant_id(self):
        # type: () -> string_types
        """Gets the tenant_id of this AzureAccount.

        The ID of your Active Directory where your subscription runs in (required)

        :return: The tenant_id of this AzureAccount.
        :rtype: string_types
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        # type: (string_types) -> None
        """Sets the tenant_id of this AzureAccount.

        The ID of your Active Directory where your subscription runs in (required)

        :param tenant_id: The tenant_id of this AzureAccount.
        :type: string_types
        """

        if tenant_id is not None:
            if not isinstance(tenant_id, string_types):
                raise TypeError("Invalid type for `tenant_id`, type has to be `string_types`")

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AzureAccount, self), "to_dict"):
            result = super(AzureAccount, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AzureAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class RtmpIngestPoint(object):
    @poscheck_model
    def __init__(self,
                 application_name=None,
                 stream_key=None):
        # type: (string_types, string_types) -> None

        self._application_name = None
        self._stream_key = None
        self.discriminator = None

        if application_name is not None:
            self.application_name = application_name
        if stream_key is not None:
            self.stream_key = stream_key

    @property
    def openapi_types(self):
        types = {
            'application_name': 'string_types',
            'stream_key': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'application_name': 'applicationName',
            'stream_key': 'streamKey'
        }
        return attributes

    @property
    def application_name(self):
        # type: () -> string_types
        """Gets the application_name of this RtmpIngestPoint.

        The name of the application where the ingest is streamed to. This has to be unique for each ingest point (required)

        :return: The application_name of this RtmpIngestPoint.
        :rtype: string_types
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        # type: (string_types) -> None
        """Sets the application_name of this RtmpIngestPoint.

        The name of the application where the ingest is streamed to. This has to be unique for each ingest point (required)

        :param application_name: The application_name of this RtmpIngestPoint.
        :type: string_types
        """

        if application_name is not None:
            if not isinstance(application_name, string_types):
                raise TypeError("Invalid type for `application_name`, type has to be `string_types`")

        self._application_name = application_name

    @property
    def stream_key(self):
        # type: () -> string_types
        """Gets the stream_key of this RtmpIngestPoint.

        The stream key for the backup input (required)

        :return: The stream_key of this RtmpIngestPoint.
        :rtype: string_types
        """
        return self._stream_key

    @stream_key.setter
    def stream_key(self, stream_key):
        # type: (string_types) -> None
        """Sets the stream_key of this RtmpIngestPoint.

        The stream key for the backup input (required)

        :param stream_key: The stream_key of this RtmpIngestPoint.
        :type: string_types
        """

        if stream_key is not None:
            if not isinstance(stream_key, string_types):
                raise TypeError("Invalid type for `stream_key`, type has to be `string_types`")

        self._stream_key = stream_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RtmpIngestPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.gce_account_region_settings import GceAccountRegionSettings
from bitmovin_api_sdk.models.google_cloud_region import GoogleCloudRegion
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.infrastructure.gce.regions.gce_account_region_settings_list_query_params import GceAccountRegionSettingsListQueryParams


class RegionsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(RegionsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, infrastructure_id, region, gce_account_region_settings, **kwargs):
        # type: (string_types, GoogleCloudRegion, GceAccountRegionSettings, dict) -> GceAccountRegionSettings
        """Add Google Cloud Region Setting

        :param infrastructure_id: Id of the Google Cloud Connect infrastructure resource
        :type infrastructure_id: string_types, required
        :param region: Google Cloud Region.
        :type region: GoogleCloudRegion, required
        :param gce_account_region_settings: The Google Cloud Region Settings to be added
        :type gce_account_region_settings: GceAccountRegionSettings, required
        :return: Google Cloud Account
        :rtype: GceAccountRegionSettings
        """

        return self.api_client.post(
            '/encoding/infrastructure/gce/{infrastructure_id}/regions/{region}',
            gce_account_region_settings,
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=GceAccountRegionSettings,
            **kwargs
        )

    def delete(self, infrastructure_id, region, **kwargs):
        # type: (string_types, GoogleCloudRegion, dict) -> GceAccountRegionSettings
        """Delete Google Cloud Region Settings

        :param infrastructure_id: Id of the Google Cloud Connect infrastructure resource
        :type infrastructure_id: string_types, required
        :param region: Google Cloud Region
        :type region: GoogleCloudRegion, required
        :return: Region settings for specified region
        :rtype: GceAccountRegionSettings
        """

        return self.api_client.delete(
            '/encoding/infrastructure/gce/{infrastructure_id}/regions/{region}',
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=GceAccountRegionSettings,
            **kwargs
        )

    def get(self, infrastructure_id, region, **kwargs):
        # type: (string_types, GoogleCloudRegion, dict) -> GceAccountRegionSettings
        """Google Cloud Region Settings Details

        :param infrastructure_id: Id of the Google Cloud Connect infrastructure resource
        :type infrastructure_id: string_types, required
        :param region: Google Cloud region.
        :type region: GoogleCloudRegion, required
        :return: Region settings for specified region
        :rtype: GceAccountRegionSettings
        """

        return self.api_client.get(
            '/encoding/infrastructure/gce/{infrastructure_id}/regions/{region}',
            path_params={'infrastructure_id': infrastructure_id, 'region': region},
            type=GceAccountRegionSettings,
            **kwargs
        )

    def list(self, infrastructure_id, query_params=None, **kwargs):
        # type: (string_types, GceAccountRegionSettingsListQueryParams, dict) -> GceAccountRegionSettings
        """List Google Cloud Region Settings

        :param infrastructure_id: Id of the Google Cloud Connect infrastructure resource
        :type infrastructure_id: string_types, required
        :param query_params: Query parameters
        :type query_params: GceAccountRegionSettingsListQueryParams
        :return: List of Google Cloud Region Settings
        :rtype: GceAccountRegionSettings
        """

        return self.api_client.get(
            '/encoding/infrastructure/gce/{infrastructure_id}/regions',
            path_params={'infrastructure_id': infrastructure_id},
            query_params=query_params,
            pagination_response=True,
            type=GceAccountRegionSettings,
            **kwargs
        )
